#!/usr/bin/ruby
# -*- encoding: utf-8 -*-
#
# rackspace dns sample code
#
# @see http://rubydoc.info/gems/fog/index
# @see https://mycloud.rackspace.com/
#
# @code
# sudo yum install ruby rubygems libxml2-devel libxslt-devel -y
# sudo gem install fog yajl-ruby
# ruby rackspace-dns.rb
# @endcode
#
# $Revision$
# $Date$
#

require 'rubygems'
require 'fog'
require 'logger'

# define
RACKSPACE_USERNAME='Your username' # Your username
RACKSPACE_API_KEY='Your API KEY' # Your API KEY
DNS_DOMAIN='yourdomain-example.com' # unique domain name
DNS_EMAIL='admin@' << DNS_DOMAIN
DNS_RECORD_NAME=DNS_DOMAIN
DNS_RECORD_TYPE='A'
DNS_RECORD_VALUE='1.2.3.4'
# /define

logger = Logger.new(STDERR)
logger.level = Logger::WARN
logger.progname = File.expand_path(__FILE__)
logger.datetime_format = "%Y-%m-%d %H:%M:%S"

begin
	# create a connection to the service
	dns = Fog::DNS.new({
		:provider     => 'rackspace',
		:rackspace_username => RACKSPACE_USERNAME,
		:rackspace_api_key => RACKSPACE_API_KEY
	})

	zone = dns.zones.find { |z| z.domain == DNS_DOMAIN }
	if zone
		puts "already exists domain: " << zone.domain
	else
		# create domain ( example.com is "Conflict error" )
		puts "create domain: " << DNS_DOMAIN
		zone = dns.zones.create(
			:domain => DNS_DOMAIN,
			:email  => DNS_EMAIL
		)
		puts "zone.nameservers: "
		puts zone.nameservers
	end

	record = zone.records.find { |r| r.name == DNS_RECORD_NAME && r.type == DNS_RECORD_TYPE }
	if record
		puts "already exists record: " << record.name << " " << record.type << " " << record.value
	else
		# create record
		puts "create record: " << DNS_DOMAIN << ' ' << DNS_RECORD_TYPE << ' ' << DNS_RECORD_VALUE
		record = zone.records.create(
		  :name => DNS_RECORD_NAME,
		  :type => DNS_RECORD_TYPE,
		  :value   => DNS_RECORD_VALUE
		)
	end
	
	# modify record
	new_record_value ='5.6.7.8'
	if record.value == DNS_RECORD_VALUE
		puts "modify record: " << record.name << " " << record.type << " " << new_record_value
		record.value = new_record_value
		record.save
	end
	
	# destory record
#	record.destroy

	# list
	for r in zone.records.all
		puts r.name << " " << r.type << " " << r.value
	end
	
rescue => err
	logger.fatal("Caught exception; exiting")
	logger.fatal(err)
end
